@@ -1,6 +1,6 @@
 set.seed(123)
 library(Bchron)
-co <- function(expr) capture.output(expr, file = "NUL")
+co <- function(expr) capture.output(expr, file = NULL)
 
 # Test all the chronologies, including some which cause problems (and so are skipped on CI and CRAN)
 
@@ -849,7 +849,7 @@ test_that("Barton_Github_20210521", {
   expect_output(summary(run3, type = "convergence"))
   expect_output(summary(run3, type = "outliers"))
   expect_output(summary(run3, type = "max_var"))
-  
+
   # Check that it reports an error when artificialThickness is zero and positions are equal
   expect_error(Bchronology(
     ages = Bchron_Frame$ages,
@@ -936,3 +936,150 @@ test_that("Barton_Github_202100604", {
   expect_output(summary(run, type = "outliers"))
   expect_output(summary(run, type = "max_var"))
 })
+
+
+# Kemp January 2023 -------------------------------------------------------
+
+test_that("Kemp_January_2023", {
+  skip_on_ci()
+  skip_on_cran()
+  
+  set.seed(123)
+  
+
+input <- structure(list(ID = c("TRY301C-334", "TRY301C-372", "TRY301C-407"), 
+                        ages = c(1640, 1980, 2260), 
+                        ageSds = c(15, 15, 15), 
+                        position = c(332,370, 405), 
+                        thickness = c(4, 4, 4), 
+                        calCurves = c("intcal20", "intcal20", "intcal20"), 
+                        Graphite = c("Traditional", "Traditional", "Traditional")), 
+                   class = c("tbl_df", "tbl", "data.frame"))
+
+cal <- 
+  BchronCalibrate(ages=input$ages,
+              ageSds=input$ageSds,
+              calCurves=input$calCurves,
+              positions=input$position,
+              ids=input$ID)
+
+run<-Bchronology(ages=input$ages,
+                    ageSds=input$ageSds,
+                    calCurves=input$calCurves,
+                    positions=input$position,
+                    positionThicknesses=input$thickness,
+                    ids=input$ID,
+                    predictPositions=seq(0,410,by=1),
+                    extractDate=-72,
+                    maxExtrap = 10000)
+
+expect_s3_class(cal, "BchronCalibratedDates")
+expect_s3_class(run, "BchronologyRun")
+expect_output(summary(run, type = "quantiles"))
+expect_output(summary(run, type = "convergence"))
+expect_output(summary(run, type = "outliers"))
+expect_output(summary(run, type = "max_var"))
+})
+
+# Shimada Feb 23 ----------------------------------------------------------
+
+test_that("Shimada_Feb_23", {
+  skip_on_ci()
+  skip_on_cran()
+  
+  set.seed(123)
+  
+  
+
+input <- structure(list(X = 1:21, id = c(
+  "top-1", "OnsetofCs137", "TKA-23298",
+  "TKA-21913", "Beta-545282", "TKA-24604", "TKA-21914", "Beta-528350",
+  "Beta-545283", "TKA-24607", "TKA-21911", "Beta-528349", "Beta-528351",
+  "Beta-545279", "Beta-528352", "Beta-528353", "Beta-528354", "Beta-545280",
+  "TKA-24606", "Beta-545281", "TKA-23299"
+), ages = c(
+  -69L, 0L,
+  209L, 303L, 260L, 653L, 901L, 820L, 660L, 1371L, 1292L, 1300L,
+  1490L, 1540L, 1480L, 1650L, 1500L, 1980L, 2040L, 2420L, 2598L
+), ageSds = c(
+  1L, 5L, 37L, 32L, 30L, 38L, 45L, 30L, 30L, 27L,
+  39L, 30L, 30L, 30L, 30L, 30L, 30L, 30L, 27L, 30L, 40L
+), position = c(
+  0,
+  69.3, 104, 122.2, 145.7, 158.6, 171.5, 189.3, 200.4, 207, 226.9,
+  235.7, 253.7, 269.8, 278.5, 291.2, 291.9, 308.9, 319.2, 329.4,
+  339
+), thickness = c(
+  0, 17, 7.2, 4.5, 1, 3.9, 3.6, 1.6, 3.6, 4,
+  4.9, 1, 2, 6, 1.7, 0.7, 0.7, 6.3, 4.5, 3.1, 5.5
+), calCurves = c(
+  "normal",
+  "normal", "intcal20", "intcal20", "intcal20", "intcal20", "intcal20",
+  "intcal20", "intcal20", "intcal20", "intcal20", "intcal20", "intcal20",
+  "intcal20", "intcal20", "intcal20", "intcal20", "intcal20", "intcal20",
+  "intcal20", "intcal20"
+)), class = "data.frame", row.names = c(
+  NA,
+  -21L
+))
+
+test <- 
+  BchronCalibrate(ages=input$ages,
+                  ageSds=input$ageSds,
+                  calCurves=input$calCurves,
+                  positions=input$position,
+                  ids=input$ID)
+# plot(test)
+
+run<-Bchronology(ages=input$ages,
+                 ageSds=input$ageSds,
+                 calCurves=input$calCurves,
+                 positions=input$position,
+                 positionThicknesses=input$thickness,
+                 ids=input$ID)
+
+expect_s3_class(run, "BchronologyRun")
+expect_output(summary(run, type = "quantiles"))
+expect_output(summary(run, type = "convergence"))
+expect_output(summary(run, type = "outliers"))
+expect_output(summary(run, type = "max_var"))
+})
+
+# Radakovic_20230312 ------------------------------------------------------
+
+test_that("Radakovic_20230312", {
+  skip_on_ci()
+  skip_on_cran()
+  
+  set.seed(123)
+  
+input <- structure(list(
+  position = c(
+    47.5, 66.5, 109, 127, 181, 209,
+    227, 245, 263, 281, 309, 327, 345, 363, 409, 529
+  ), Depth_error_.cm. = c(
+    4L,
+    4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L
+  ),
+  ages = c(
+    7400L, 15600L, 13600L, 18800L, 17100L, 19700L,
+    27800L, 25800L, 31300L, 24600L, 29800L, 34200L, 35800L, 37500L,
+    43600L, 49800L
+  ), ageSds = c(
+    700L, 1200L, 1000L, 1600L,
+    1700L, 1700L, 2100L, 2300L, 2900L, 2600L, 5800L, 2400L, 3700L,
+    2300L, 2600L, 3000L
+  )
+), class = "data.frame", row.names = c(
+  NA,
+  -16L
+))
+
+expect_warning(with(input,
+            BchronCalibrate(ages = 100 * ages,
+                            ageSds = 100 * ageSds,
+                            positions = position,
+                            calCurves = rep("normal", length(ages)))))
+
+# plot(test)
+})
\ No newline at end of file
